@@ -671,58 +671,6 @@ impl AsReadWriteHandleOrSocket for mio::net::TcpStream {
     }
 }
 
-#[cfg(all(not(windows), feature = "use_mio_net"))]
-impl AsRawReadWriteFd for mio::net::TcpSocket {
-    #[inline]
-    fn as_raw_read_fd(&self) -> RawFd {
-        self.as_raw_fd()
-    }
-
-    #[inline]
-    fn as_raw_write_fd(&self) -> RawFd {
-        self.as_raw_fd()
-    }
-}
-
-#[cfg(all(not(windows), feature = "use_mio_net"))]
-impl AsReadWriteFd for mio::net::TcpSocket {
-    #[inline]
-    fn as_read_fd(&self) -> BorrowedFd<'_> {
-        self.as_fd()
-    }
-
-    #[inline]
-    fn as_write_fd(&self) -> BorrowedFd<'_> {
-        self.as_fd()
-    }
-}
-
-#[cfg(all(windows, feature = "use_mio_net"))]
-impl AsRawReadWriteHandleOrSocket for mio::net::TcpSocket {
-    #[inline]
-    fn as_raw_read_handle_or_socket(&self) -> RawHandleOrSocket {
-        self.as_raw_handle_or_socket()
-    }
-
-    #[inline]
-    fn as_raw_write_handle_or_socket(&self) -> RawHandleOrSocket {
-        self.as_raw_handle_or_socket()
-    }
-}
-
-#[cfg(all(windows, feature = "use_mio_net"))]
-impl AsReadWriteHandleOrSocket for mio::net::TcpSocket {
-    #[inline]
-    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
-        self.as_handle_or_socket()
-    }
-
-    #[inline]
-    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
-        self.as_handle_or_socket()
-    }
-}
-
 #[cfg(all(not(windows), feature = "use_mio_net"))]
 impl AsRawReadWriteFd for mio::net::UdpSocket {
     #[inline]
